==> physx-jni-0.4.16-sources.jar: physx/physics/PxActor.java <==
package physx.physics;

import physx.NativeObject;
import physx.common.PxBase;
import physx.common.PxBounds3;

public class PxActor extends PxBase {

    protected PxActor() { }

    public static PxActor wrapPointer(long address) {
        return address != 0L ? new PxActor(address) : null;
    }
    
    protected PxActor(long address) {
        super(address);
    }

    // Attributes

    /**
     * @return WebIDL type: VoidPtr
     */
    public NativeObject getUserData() {
        checkNotNull();
        return NativeObject.wrapPointer(_getUserData(address));
    }
    private static native long _getUserData(long address);

    /**
     * @param value WebIDL type: VoidPtr
     */
    public void setUserData(NativeObject value) {
        checkNotNull();
        _setUserData(address, value.getAddress());
    }
    private static native void _setUserData(long address, long value);

    // Functions

    /**
     * @return WebIDL type: {@link PxActorTypeEnum} [enum]
     */
    public int getType() {
        checkNotNull();
        return _getType(address);
    }
    private static native int _getType(long address);

    /**
     * @return WebIDL type: {@link PxScene}
     */
    public PxScene getScene() {
        checkNotNull();
        return PxScene.wrapPointer(_getScene(address));
    }
    private static native long _getScene(long address);

    /**
     * @param name WebIDL type: DOMString
     */
    public void setName(String name) {
        checkNotNull();
        _setName(address, name);
    }
    private static native void _setName(long address, String name);

    /**
     * @return WebIDL type: DOMString [Const]
     */
    public String getName() {
        checkNotNull();
        return _getName(address);
    }
    private static native String _getName(long address);

    /**
     * @return WebIDL type: {@link PxBounds3} [Value]
     */
    public PxBounds3 getWorldBounds() {
        checkNotNull();
        return PxBounds3.wrapPointer(_getWorldBounds(address));
    }
    private static native long _getWorldBounds(long address);

    /**
     * @param inflation WebIDL type: float
     * @return WebIDL type: {@link PxBounds3} [Value]
     */
    public PxBounds3 getWorldBounds(float inflation) {
        checkNotNull();
        return PxBounds3.wrapPointer(_getWorldBounds(address, inflation));
    }
    private static native long _getWorldBounds(long address, float inflation);

    /**
     * @param flags WebIDL type: {@link PxActorFlags} [Ref]
     */
    public void setActorFlags(PxActorFlags flags) {
        checkNotNull();
        _setActorFlags(address, flags.getAddress());
    }
    private static native void _setActorFlags(long address, long flags);

    /**
     * @return WebIDL type: {@link PxActorFlags} [Value]
     */
    public PxActorFlags getActorFlags() {
        checkNotNull();
        return PxActorFlags.wrapPointer(_getActorFlags(address));
    }
    private static native long _getActorFlags(long address);

    /**
     * @param dominanceGroup WebIDL type: octet
     */
    public void setDominanceGroup(byte dominanceGroup) {
        checkNotNull();
        _setDominanceGroup(address, dominanceGroup);
    }
    private static native void _setDominanceGroup(long address, byte dominanceGroup);

    /**
     * @return WebIDL type: octet
     */
    public byte getDominanceGroup() {
        checkNotNull();
        return _getDominanceGroup(address);
    }
    private static native byte _getDominanceGroup(long address);

    /**
     * @param inClient WebIDL type: octet
     */
    public void setOwnerClient(byte inClient) {
        checkNotNull();
        _setOwnerClient(address, inClient);
    }
    private static native void _setOwnerClient(long address, byte inClient);

    /**
     * @return WebIDL type: octet
     */
    public byte getOwnerClient() {
        checkNotNull();
        return _getOwnerClient(address);
    }
    private static native byte _getOwnerClient(long address);

}

==> physx-jni-1.1.0-sources.jar: physx/physics/PxActor.java <==
package physx.physics;

import physx.NativeObject;
import physx.common.PxBase;
import physx.common.PxBounds3;

public class PxActor extends PxBase {

    protected PxActor() { }

    public static PxActor wrapPointer(long address) {
        return address != 0L ? new PxActor(address) : null;
    }
    
    protected PxActor(long address) {
        super(address);
    }

    // Attributes

    /**
     * @return WebIDL type: VoidPtr
     */
    public NativeObject getUserData() {
        checkNotNull();
        return NativeObject.wrapPointer(_getUserData(address));
    }
    private static native long _getUserData(long address);

    /**
     * @param value WebIDL type: VoidPtr
     */
    public void setUserData(NativeObject value) {
        checkNotNull();
        _setUserData(address, value.getAddress());
    }
    private static native void _setUserData(long address, long value);

    // Functions

    /**
     * @return WebIDL type: {@link PxActorTypeEnum} [enum]
     */
    public int getType() {
        checkNotNull();
        return _getType(address);
    }
    private static native int _getType(long address);

    /**
     * @return WebIDL type: {@link PxScene}
     */
    public PxScene getScene() {
        checkNotNull();
        return PxScene.wrapPointer(_getScene(address));
    }
    private static native long _getScene(long address);

    /**
     * @param name WebIDL type: DOMString
     */
    public void setName(String name) {
        checkNotNull();
        _setName(address, name);
    }
    private static native void _setName(long address, String name);

    /**
     * @return WebIDL type: DOMString [Const]
     */
    public String getName() {
        checkNotNull();
        return _getName(address);
    }
    private static native String _getName(long address);

    /**
     * @return WebIDL type: {@link PxBounds3} [Value]
     */
    public PxBounds3 getWorldBounds() {
        checkNotNull();
        return PxBounds3.wrapPointer(_getWorldBounds(address));
    }
    private static native long _getWorldBounds(long address);

    /**
     * @param inflation WebIDL type: float
     * @return WebIDL type: {@link PxBounds3} [Value]
     */
    public PxBounds3 getWorldBounds(float inflation) {
        checkNotNull();
        return PxBounds3.wrapPointer(_getWorldBounds(address, inflation));
    }
    private static native long _getWorldBounds(long address, float inflation);

    /**
     * @param flag  WebIDL type: {@link PxActorFlagEnum} [enum]
     * @param value WebIDL type: boolean
     */
    public void setActorFlag(int flag, boolean value) {
        checkNotNull();
        _setActorFlag(address, flag, value);
    }
    private static native void _setActorFlag(long address, int flag, boolean value);

    /**
     * @param flags WebIDL type: {@link PxActorFlags} [Ref]
     */
    public void setActorFlags(PxActorFlags flags) {
        checkNotNull();
        _setActorFlags(address, flags.getAddress());
    }
    private static native void _setActorFlags(long address, long flags);

    /**
     * @return WebIDL type: {@link PxActorFlags} [Value]
     */
    public PxActorFlags getActorFlags() {
        checkNotNull();
        return PxActorFlags.wrapPointer(_getActorFlags(address));
    }
    private static native long _getActorFlags(long address);

    /**
     * @param dominanceGroup WebIDL type: octet
     */
    public void setDominanceGroup(byte dominanceGroup) {
        checkNotNull();
        _setDominanceGroup(address, dominanceGroup);
    }
    private static native void _setDominanceGroup(long address, byte dominanceGroup);

    /**
     * @return WebIDL type: octet
     */
    public byte getDominanceGroup() {
        checkNotNull();
        return _getDominanceGroup(address);
    }
    private static native byte _getDominanceGroup(long address);

    /**
     * @param inClient WebIDL type: octet
     */
    public void setOwnerClient(byte inClient) {
        checkNotNull();
        _setOwnerClient(address, inClient);
    }
    private static native void _setOwnerClient(long address, byte inClient);

    /**
     * @return WebIDL type: octet
     */
    public byte getOwnerClient() {
        checkNotNull();
        return _getOwnerClient(address);
    }
    private static native byte _getOwnerClient(long address);

}
